/**
 * @packageDocumentation
 * @module @proc7ts/a-iterable
 */
import { RevertibleIterable } from './revertible-iterable';
/**
 * Starts iteration over the given `iterable`.
 *
 * This is a shortcut for `iterable[Symbol.iterator]` to make it friendlier to minification.
 *
 * @param iterable  An iterable to iterate over.
 *
 * @return An iterator.
 */
export declare function itsIterator<T>(iterable: Iterable<T>): Iterator<T>;
/**
 * Builds an iterable iterator over the given `iterable`.
 *
 * @param iterable  An iterable to iterate over.
 *
 * @return An iterator.
 */
export declare function itsIterable<T>(iterable: Iterable<T>): IterableIterator<T>;
/**
 * Creates custom iterable.
 *
 * @param iterate  A no-arg function constructing an iterator.
 * @param reverse  When `undefined` or unspecified the created iterable won't be reversible.
 *
 * @returns New iterable.
 */
export declare function makeIt<T>(iterate: (this: Iterable<T>) => Iterator<T>, reverse?: undefined): Iterable<T>;
/**
 * Creates custom revertible iterable.
 *
 * @param iterate  A no-arg function constructing an iterator.
 * @param reverse  A no-arg function constructing a reverse iterable.
 *
 * @returns New reversible iterable.
 */
export declare function makeIt<T>(iterate: (this: RevertibleIterable<T>) => Iterator<T>, reverse: (this: RevertibleIterable<T>) => Iterable<T>): RevertibleIterable<T>;
//# sourceMappingURL=util.d.ts.map